// Code generated by protoc-gen-go. DO NOT EDIT.
// source: envoy/config/filter/http/jwt_authn/v2alpha/config.proto

package envoy_config_filter_http_jwt_authn_v2alpha

import proto "github.com/golang/protobuf/proto"
import fmt "fmt"
import math "math"
import core "github.com/cilium/cilium/pkg/envoy/envoy/api/v2/core"
import route "github.com/cilium/cilium/pkg/envoy/envoy/api/v2/route"
import duration "github.com/golang/protobuf/ptypes/duration"
import _ "github.com/lyft/protoc-gen-validate/validate"

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion2 // please upgrade the proto package

// This message specifies how a JSON Web Token (JWT) can be verified. JWT format is defined
// `here <https://tools.ietf.org/html/rfc7519>`_. Please see `OAuth2.0
//  <https://tools.ietf.org/html/rfc6749>`_ and `OIDC1.0  <http://openid.net/connect>`_ for
// the authentication flow.
//
// Example:
//
// .. code-block:: yaml
//
//     issuer: https://example.com
//     audiences:
//     - bookstore_android.apps.googleusercontent.com
//       bookstore_web.apps.googleusercontent.com
//     remote_jwks:
//     - http_uri:
//       - uri: https://example.com/.well-known/jwks.json
//         cluster: example_jwks_cluster
//       cache_duration:
//       - seconds: 300
//
// [#not-implemented-hide:]
type JwtRule struct {
	// Identifies the principal that issued the JWT. See `here
	//  <https://tools.ietf.org/html/rfc7519#section-4.1.1>`_. Usually a URL or an email address.
	//
	// Example: https://securetoken.google.com
	// Example: 1234567-compute@developer.gserviceaccount.com
	//
	Issuer string `protobuf:"bytes,1,opt,name=issuer" json:"issuer,omitempty"`
	// The list of JWT `audiences <https://tools.ietf.org/html/rfc7519#section-4.1.3>`_. that are
	// allowed to access. A JWT containing any of these audiences will be accepted. If not specified,
	// will not check audiences in the token.
	//
	// Example:
	//
	// .. code-block:: yaml
	//
	//     audiences:
	//     - bookstore_android.apps.googleusercontent.com
	//       bookstore_web.apps.googleusercontent.com
	//
	Audiences []string `protobuf:"bytes,2,rep,name=audiences" json:"audiences,omitempty"`
	// `JSON Web Key Set <https://tools.ietf.org/html/rfc7517#appendix-A>`_ is needed. to validate
	// signature of the JWT. This field specifies where to fetch JWKS.
	//
	// Types that are valid to be assigned to JwksSourceSpecifier:
	//	*JwtRule_RemoteJwks
	//	*JwtRule_LocalJwks
	JwksSourceSpecifier isJwtRule_JwksSourceSpecifier `protobuf_oneof:"jwks_source_specifier"`
	// If false, the JWT is removed in the request after a success verification. If true, the JWT is
	// not removed in the request. Default value is false.
	Forward bool `protobuf:"varint,5,opt,name=forward" json:"forward,omitempty"`
	// Specify the HTTP headers to extract JWT token. For examples, following config:
	//
	// .. code-block:: yaml
	//
	//   from_headers:
	//   - name: x-goog-iap-jwt-assertion
	//
	// can be used to extract token from header::
	//
	//   x-goog-iap-jwt-assertion: <JWT>.
	//
	FromHeaders []*JwtHeader `protobuf:"bytes,6,rep,name=from_headers,json=fromHeaders" json:"from_headers,omitempty"`
	// JWT is sent in a query parameter. `jwt_params` represents the query parameter names.
	//
	// For example, if config is:
	//
	// .. code-block:: yaml
	//
	//   from_params:
	//   - jwt_token
	//
	// The JWT format in query parameter is::
	//
	//    /path?jwt_token=<JWT>
	//
	FromParams []string `protobuf:"bytes,7,rep,name=from_params,json=fromParams" json:"from_params,omitempty"`
	// This field specifies the header name to forward a successfully verified JWT payload to the
	// backend. The forwarded data is::
	//
	//    base64_encoded(jwt_payload_in_JSON)
	//
	// If it is not specified, the payload will not be forwarded.
	// Multiple JWTs in a request from different issuers will be supported. Multiple JWTs from the
	// same issuer will not be supported. Each issuer can config this `forward_payload_header`. If
	// multiple JWTs from different issuers want to forward their payloads, their
	// `forward_payload_header` should be different.
	ForwardPayloadHeader string   `protobuf:"bytes,8,opt,name=forward_payload_header,json=forwardPayloadHeader" json:"forward_payload_header,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *JwtRule) Reset()         { *m = JwtRule{} }
func (m *JwtRule) String() string { return proto.CompactTextString(m) }
func (*JwtRule) ProtoMessage()    {}
func (*JwtRule) Descriptor() ([]byte, []int) {
	return fileDescriptor_config_15db2054d3d4b83e, []int{0}
}
func (m *JwtRule) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_JwtRule.Unmarshal(m, b)
}
func (m *JwtRule) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_JwtRule.Marshal(b, m, deterministic)
}
func (dst *JwtRule) XXX_Merge(src proto.Message) {
	xxx_messageInfo_JwtRule.Merge(dst, src)
}
func (m *JwtRule) XXX_Size() int {
	return xxx_messageInfo_JwtRule.Size(m)
}
func (m *JwtRule) XXX_DiscardUnknown() {
	xxx_messageInfo_JwtRule.DiscardUnknown(m)
}

var xxx_messageInfo_JwtRule proto.InternalMessageInfo

type isJwtRule_JwksSourceSpecifier interface {
	isJwtRule_JwksSourceSpecifier()
}

type JwtRule_RemoteJwks struct {
	RemoteJwks *RemoteJwks `protobuf:"bytes,3,opt,name=remote_jwks,json=remoteJwks,oneof"`
}
type JwtRule_LocalJwks struct {
	LocalJwks *core.DataSource `protobuf:"bytes,4,opt,name=local_jwks,json=localJwks,oneof"`
}

func (*JwtRule_RemoteJwks) isJwtRule_JwksSourceSpecifier() {}
func (*JwtRule_LocalJwks) isJwtRule_JwksSourceSpecifier()  {}

func (m *JwtRule) GetJwksSourceSpecifier() isJwtRule_JwksSourceSpecifier {
	if m != nil {
		return m.JwksSourceSpecifier
	}
	return nil
}

func (m *JwtRule) GetIssuer() string {
	if m != nil {
		return m.Issuer
	}
	return ""
}

func (m *JwtRule) GetAudiences() []string {
	if m != nil {
		return m.Audiences
	}
	return nil
}

func (m *JwtRule) GetRemoteJwks() *RemoteJwks {
	if x, ok := m.GetJwksSourceSpecifier().(*JwtRule_RemoteJwks); ok {
		return x.RemoteJwks
	}
	return nil
}

func (m *JwtRule) GetLocalJwks() *core.DataSource {
	if x, ok := m.GetJwksSourceSpecifier().(*JwtRule_LocalJwks); ok {
		return x.LocalJwks
	}
	return nil
}

func (m *JwtRule) GetForward() bool {
	if m != nil {
		return m.Forward
	}
	return false
}

func (m *JwtRule) GetFromHeaders() []*JwtHeader {
	if m != nil {
		return m.FromHeaders
	}
	return nil
}

func (m *JwtRule) GetFromParams() []string {
	if m != nil {
		return m.FromParams
	}
	return nil
}

func (m *JwtRule) GetForwardPayloadHeader() string {
	if m != nil {
		return m.ForwardPayloadHeader
	}
	return ""
}

// XXX_OneofFuncs is for the internal use of the proto package.
func (*JwtRule) XXX_OneofFuncs() (func(msg proto.Message, b *proto.Buffer) error, func(msg proto.Message, tag, wire int, b *proto.Buffer) (bool, error), func(msg proto.Message) (n int), []interface{}) {
	return _JwtRule_OneofMarshaler, _JwtRule_OneofUnmarshaler, _JwtRule_OneofSizer, []interface{}{
		(*JwtRule_RemoteJwks)(nil),
		(*JwtRule_LocalJwks)(nil),
	}
}

func _JwtRule_OneofMarshaler(msg proto.Message, b *proto.Buffer) error {
	m := msg.(*JwtRule)
	// jwks_source_specifier
	switch x := m.JwksSourceSpecifier.(type) {
	case *JwtRule_RemoteJwks:
		b.EncodeVarint(3<<3 | proto.WireBytes)
		if err := b.EncodeMessage(x.RemoteJwks); err != nil {
			return err
		}
	case *JwtRule_LocalJwks:
		b.EncodeVarint(4<<3 | proto.WireBytes)
		if err := b.EncodeMessage(x.LocalJwks); err != nil {
			return err
		}
	case nil:
	default:
		return fmt.Errorf("JwtRule.JwksSourceSpecifier has unexpected type %T", x)
	}
	return nil
}

func _JwtRule_OneofUnmarshaler(msg proto.Message, tag, wire int, b *proto.Buffer) (bool, error) {
	m := msg.(*JwtRule)
	switch tag {
	case 3: // jwks_source_specifier.remote_jwks
		if wire != proto.WireBytes {
			return true, proto.ErrInternalBadWireType
		}
		msg := new(RemoteJwks)
		err := b.DecodeMessage(msg)
		m.JwksSourceSpecifier = &JwtRule_RemoteJwks{msg}
		return true, err
	case 4: // jwks_source_specifier.local_jwks
		if wire != proto.WireBytes {
			return true, proto.ErrInternalBadWireType
		}
		msg := new(core.DataSource)
		err := b.DecodeMessage(msg)
		m.JwksSourceSpecifier = &JwtRule_LocalJwks{msg}
		return true, err
	default:
		return false, nil
	}
}

func _JwtRule_OneofSizer(msg proto.Message) (n int) {
	m := msg.(*JwtRule)
	// jwks_source_specifier
	switch x := m.JwksSourceSpecifier.(type) {
	case *JwtRule_RemoteJwks:
		s := proto.Size(x.RemoteJwks)
		n += 1 // tag and wire
		n += proto.SizeVarint(uint64(s))
		n += s
	case *JwtRule_LocalJwks:
		s := proto.Size(x.LocalJwks)
		n += 1 // tag and wire
		n += proto.SizeVarint(uint64(s))
		n += s
	case nil:
	default:
		panic(fmt.Sprintf("proto: unexpected type %T in oneof", x))
	}
	return n
}

// This message specifies how to fetch JWKS from remote and how to cache it.
type RemoteJwks struct {
	// The HTTP URI to fetch the JWKS. For example:
	//
	// .. code-block:: yaml
	//
	//    http_uri:
	//    - uri: https://www.googleapis.com/oauth2/v1/certs
	//      cluster: jwt.www.googleapis.com|443
	//
	HttpUri *core.HttpUri `protobuf:"bytes,1,opt,name=http_uri,json=httpUri" json:"http_uri,omitempty"`
	// Duration after which the cached JWKS should be expired. If not specified, default cache
	// duration is 5 minutes.
	CacheDuration        *duration.Duration `protobuf:"bytes,2,opt,name=cache_duration,json=cacheDuration" json:"cache_duration,omitempty"`
	XXX_NoUnkeyedLiteral struct{}           `json:"-"`
	XXX_unrecognized     []byte             `json:"-"`
	XXX_sizecache        int32              `json:"-"`
}

func (m *RemoteJwks) Reset()         { *m = RemoteJwks{} }
func (m *RemoteJwks) String() string { return proto.CompactTextString(m) }
func (*RemoteJwks) ProtoMessage()    {}
func (*RemoteJwks) Descriptor() ([]byte, []int) {
	return fileDescriptor_config_15db2054d3d4b83e, []int{1}
}
func (m *RemoteJwks) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_RemoteJwks.Unmarshal(m, b)
}
func (m *RemoteJwks) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_RemoteJwks.Marshal(b, m, deterministic)
}
func (dst *RemoteJwks) XXX_Merge(src proto.Message) {
	xxx_messageInfo_RemoteJwks.Merge(dst, src)
}
func (m *RemoteJwks) XXX_Size() int {
	return xxx_messageInfo_RemoteJwks.Size(m)
}
func (m *RemoteJwks) XXX_DiscardUnknown() {
	xxx_messageInfo_RemoteJwks.DiscardUnknown(m)
}

var xxx_messageInfo_RemoteJwks proto.InternalMessageInfo

func (m *RemoteJwks) GetHttpUri() *core.HttpUri {
	if m != nil {
		return m.HttpUri
	}
	return nil
}

func (m *RemoteJwks) GetCacheDuration() *duration.Duration {
	if m != nil {
		return m.CacheDuration
	}
	return nil
}

// This message specifies a header location to extract JWT token.
type JwtHeader struct {
	// The HTTP header name.
	Name string `protobuf:"bytes,1,opt,name=name" json:"name,omitempty"`
	// The value prefix. The value format is "value_prefix<token>"
	// For example, for "Authorization: Bearer <token>", value_prefix="Bearer " with a space at the
	// end.
	ValuePrefix          string   `protobuf:"bytes,2,opt,name=value_prefix,json=valuePrefix" json:"value_prefix,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *JwtHeader) Reset()         { *m = JwtHeader{} }
func (m *JwtHeader) String() string { return proto.CompactTextString(m) }
func (*JwtHeader) ProtoMessage()    {}
func (*JwtHeader) Descriptor() ([]byte, []int) {
	return fileDescriptor_config_15db2054d3d4b83e, []int{2}
}
func (m *JwtHeader) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_JwtHeader.Unmarshal(m, b)
}
func (m *JwtHeader) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_JwtHeader.Marshal(b, m, deterministic)
}
func (dst *JwtHeader) XXX_Merge(src proto.Message) {
	xxx_messageInfo_JwtHeader.Merge(dst, src)
}
func (m *JwtHeader) XXX_Size() int {
	return xxx_messageInfo_JwtHeader.Size(m)
}
func (m *JwtHeader) XXX_DiscardUnknown() {
	xxx_messageInfo_JwtHeader.DiscardUnknown(m)
}

var xxx_messageInfo_JwtHeader proto.InternalMessageInfo

func (m *JwtHeader) GetName() string {
	if m != nil {
		return m.Name
	}
	return ""
}

func (m *JwtHeader) GetValuePrefix() string {
	if m != nil {
		return m.ValuePrefix
	}
	return ""
}

// This is the Envoy HTTP filter config for JWT authentication.
// [#not-implemented-hide:]
type JwtAuthentication struct {
	// List of JWT rules to valide.
	Rules []*JwtRule `protobuf:"bytes,1,rep,name=rules" json:"rules,omitempty"`
	// If true, the request is allowed if JWT is missing or JWT verification fails.
	// Default is false, a request without JWT or failed JWT verification is not allowed.
	AllowMissingOrFailed bool `protobuf:"varint,2,opt,name=allow_missing_or_failed,json=allowMissingOrFailed" json:"allow_missing_or_failed,omitempty"`
	// This field lists the patterns allowed to bypass JWT verification. This only applies when
	// `allow_missing_or_failed_jwt` is false. Under this config, if a request doesn't have JWT, it
	// will be rejected. But some requests still needed to be forwarded without JWT, such as OPTIONS
	// for CORS and some health checking paths.
	//
	// Examples: bypass all CORS options requests
	//
	// .. code-block:: yaml
	//
	//   bypass:
	//   - headers:
	//     - name: :method
	//       value: OPTIONS
	//   - headers:
	//     - name: :path
	//       regex_match: /.*
	//
	// Examples: bypass /healthz check
	//
	// .. code-block:: yaml
	//
	//   bypass:
	//   - headers:
	//     - name: :method
	//       value: GET
	//   - headers:
	//     - name: :path
	//       exact_match: /healthz
	//
	Bypass               []*route.RouteMatch `protobuf:"bytes,3,rep,name=bypass" json:"bypass,omitempty"`
	XXX_NoUnkeyedLiteral struct{}            `json:"-"`
	XXX_unrecognized     []byte              `json:"-"`
	XXX_sizecache        int32               `json:"-"`
}

func (m *JwtAuthentication) Reset()         { *m = JwtAuthentication{} }
func (m *JwtAuthentication) String() string { return proto.CompactTextString(m) }
func (*JwtAuthentication) ProtoMessage()    {}
func (*JwtAuthentication) Descriptor() ([]byte, []int) {
	return fileDescriptor_config_15db2054d3d4b83e, []int{3}
}
func (m *JwtAuthentication) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_JwtAuthentication.Unmarshal(m, b)
}
func (m *JwtAuthentication) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_JwtAuthentication.Marshal(b, m, deterministic)
}
func (dst *JwtAuthentication) XXX_Merge(src proto.Message) {
	xxx_messageInfo_JwtAuthentication.Merge(dst, src)
}
func (m *JwtAuthentication) XXX_Size() int {
	return xxx_messageInfo_JwtAuthentication.Size(m)
}
func (m *JwtAuthentication) XXX_DiscardUnknown() {
	xxx_messageInfo_JwtAuthentication.DiscardUnknown(m)
}

var xxx_messageInfo_JwtAuthentication proto.InternalMessageInfo

func (m *JwtAuthentication) GetRules() []*JwtRule {
	if m != nil {
		return m.Rules
	}
	return nil
}

func (m *JwtAuthentication) GetAllowMissingOrFailed() bool {
	if m != nil {
		return m.AllowMissingOrFailed
	}
	return false
}

func (m *JwtAuthentication) GetBypass() []*route.RouteMatch {
	if m != nil {
		return m.Bypass
	}
	return nil
}

func init() {
	proto.RegisterType((*JwtRule)(nil), "envoy.config.filter.http.jwt_authn.v2alpha.JwtRule")
	proto.RegisterType((*RemoteJwks)(nil), "envoy.config.filter.http.jwt_authn.v2alpha.RemoteJwks")
	proto.RegisterType((*JwtHeader)(nil), "envoy.config.filter.http.jwt_authn.v2alpha.JwtHeader")
	proto.RegisterType((*JwtAuthentication)(nil), "envoy.config.filter.http.jwt_authn.v2alpha.JwtAuthentication")
}

func init() {
	proto.RegisterFile("envoy/config/filter/http/jwt_authn/v2alpha/config.proto", fileDescriptor_config_15db2054d3d4b83e)
}

var fileDescriptor_config_15db2054d3d4b83e = []byte{
	// 626 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x94, 0x53, 0xd1, 0x4e, 0xdb, 0x3c,
	0x14, 0x26, 0x14, 0xda, 0xc6, 0xe5, 0xff, 0xa5, 0x59, 0x6c, 0x64, 0x08, 0x58, 0xe8, 0x55, 0xb5,
	0x8b, 0x44, 0x2a, 0x83, 0xdd, 0x4d, 0x1b, 0x42, 0x53, 0x57, 0x09, 0x0d, 0x79, 0x9a, 0xb4, 0x5d,
	0x45, 0xa7, 0x89, 0xd3, 0x18, 0xdc, 0x38, 0xb2, 0x9d, 0x66, 0x3c, 0xc0, 0xde, 0x69, 0xda, 0x15,
	0x2f, 0x30, 0x69, 0xaf, 0xc1, 0x5b, 0x4c, 0xb1, 0x93, 0x22, 0xc4, 0x2e, 0xc6, 0x8d, 0xe5, 0x73,
	0xbe, 0xf3, 0x7d, 0x3e, 0xf9, 0xce, 0x09, 0x7a, 0x4d, 0xf3, 0xa5, 0xb8, 0x0e, 0x63, 0x91, 0xa7,
	0x6c, 0x1e, 0xa6, 0x8c, 0x6b, 0x2a, 0xc3, 0x4c, 0xeb, 0x22, 0xbc, 0xac, 0x74, 0x04, 0xa5, 0xce,
	0xf2, 0x70, 0x39, 0x06, 0x5e, 0x64, 0xd0, 0x14, 0x05, 0x85, 0x14, 0x5a, 0xe0, 0x97, 0x86, 0x18,
	0x34, 0x39, 0x4b, 0x0c, 0x6a, 0x62, 0xb0, 0x22, 0x06, 0x0d, 0x71, 0x77, 0xcf, 0x3e, 0x02, 0x05,
	0x0b, 0x97, 0xe3, 0x30, 0x16, 0x92, 0x86, 0x33, 0x50, 0xd4, 0x2a, 0xed, 0xfa, 0x0f, 0xd1, 0x5a,
	0x27, 0x2a, 0x25, 0x6b, 0x2a, 0x0e, 0xee, 0x55, 0x48, 0x51, 0x6a, 0x6a, 0xcf, 0x16, 0x9f, 0x0b,
	0x31, 0xe7, 0x34, 0x34, 0xd1, 0xac, 0x4c, 0xc3, 0xa4, 0x94, 0xa0, 0x99, 0xc8, 0x1b, 0x7c, 0x67,
	0x09, 0x9c, 0x25, 0xa0, 0x69, 0xd8, 0x5e, 0x2c, 0x30, 0xfc, 0xdd, 0x41, 0xbd, 0x69, 0xa5, 0x49,
	0xc9, 0x29, 0x3e, 0x44, 0x5d, 0xa6, 0x54, 0x49, 0xa5, 0xe7, 0xf8, 0xce, 0xc8, 0x3d, 0x75, 0x7f,
	0xde, 0xde, 0x74, 0x36, 0xe4, 0xba, 0xef, 0x90, 0x06, 0xc0, 0x7b, 0xc8, 0x85, 0x32, 0x61, 0x34,
	0x8f, 0xa9, 0xf2, 0xd6, 0xfd, 0xce, 0xc8, 0x25, 0x77, 0x09, 0xfc, 0x15, 0x0d, 0x24, 0x5d, 0x08,
	0x4d, 0xa3, 0xcb, 0xea, 0x4a, 0x79, 0x1d, 0xdf, 0x19, 0x0d, 0xc6, 0x27, 0xc1, 0xbf, 0xfb, 0x14,
	0x10, 0x43, 0x9f, 0x56, 0x57, 0x6a, 0xb2, 0x46, 0x90, 0x5c, 0x45, 0xf8, 0x0d, 0x42, 0x5c, 0xc4,
	0xc0, 0xad, 0xf2, 0x86, 0x51, 0xde, 0x6f, 0x94, 0xa1, 0x60, 0xc1, 0x72, 0x1c, 0xd4, 0xbe, 0x05,
	0x67, 0xa0, 0xe1, 0x93, 0x28, 0x65, 0x4c, 0x27, 0x6b, 0xc4, 0x35, 0x14, 0xc3, 0xf7, 0x50, 0x2f,
	0x15, 0xb2, 0x02, 0x99, 0x78, 0x9b, 0xbe, 0x33, 0xea, 0x93, 0x36, 0xc4, 0x5f, 0xd0, 0x56, 0x2a,
	0xc5, 0x22, 0xca, 0x28, 0x24, 0x54, 0x2a, 0xaf, 0xeb, 0x77, 0x46, 0x83, 0xf1, 0xf1, 0x63, 0xba,
	0x9e, 0x56, 0x7a, 0x62, 0xd8, 0x64, 0x50, 0x4b, 0xd9, 0xbb, 0xc2, 0x2f, 0x90, 0x09, 0xa3, 0x02,
	0x24, 0x2c, 0x94, 0xd7, 0x33, 0x76, 0xa1, 0x3a, 0x75, 0x61, 0x32, 0xf8, 0x15, 0x7a, 0xd6, 0x74,
	0x11, 0x15, 0x70, 0xcd, 0x05, 0x24, 0x4d, 0x17, 0x5e, 0xbf, 0x1e, 0x00, 0xd9, 0x6e, 0xd0, 0x0b,
	0x0b, 0x5a, 0xdd, 0xd3, 0x03, 0xf4, 0xb4, 0x36, 0x21, 0x52, 0xe6, 0x33, 0x23, 0x55, 0xd0, 0x98,
	0xa5, 0x8c, 0x4a, 0xbc, 0xf9, 0xe3, 0xf6, 0xa6, 0xe3, 0x0c, 0xbf, 0x3b, 0x08, 0xdd, 0xf9, 0x88,
	0x8f, 0x51, 0xbf, 0x5d, 0x26, 0x33, 0xd7, 0xc1, 0x78, 0xf7, 0x2f, 0xbe, 0x4d, 0xb4, 0x2e, 0x3e,
	0x4b, 0x46, 0x7a, 0x99, 0xbd, 0xe0, 0xb7, 0xe8, 0xff, 0x18, 0xe2, 0x8c, 0x46, 0xed, 0x26, 0x79,
	0xeb, 0x86, 0xfc, 0x3c, 0xb0, 0xab, 0x16, 0xb4, 0xab, 0x16, 0x9c, 0x35, 0x05, 0xe4, 0x3f, 0x43,
	0x68, 0xc3, 0xe1, 0x39, 0x72, 0x57, 0xc6, 0xe0, 0x7d, 0xb4, 0x91, 0xc3, 0x82, 0x3e, 0xdc, 0x2c,
	0x93, 0xc6, 0x87, 0x68, 0x6b, 0x09, 0xbc, 0xa4, 0x51, 0x21, 0x69, 0xca, 0xbe, 0x99, 0xb7, 0x5c,
	0x32, 0x30, 0xb9, 0x0b, 0x93, 0x1a, 0xfe, 0x72, 0xd0, 0x93, 0x69, 0xa5, 0xdf, 0x95, 0x3a, 0xa3,
	0xb9, 0x66, 0xb1, 0x79, 0x04, 0x7f, 0x40, 0x9b, 0xb2, 0xe4, 0x54, 0x79, 0x8e, 0x19, 0xdb, 0xd1,
	0x23, 0xc7, 0x56, 0xef, 0x3d, 0xb1, 0x0a, 0xf8, 0x18, 0xed, 0x00, 0xe7, 0xa2, 0x8a, 0x16, 0x4c,
	0x29, 0x96, 0xcf, 0x23, 0x21, 0xa3, 0x14, 0x18, 0xa7, 0x89, 0x69, 0xa7, 0x4f, 0xb6, 0x0d, 0x7c,
	0x6e, 0xd1, 0x8f, 0xf2, 0xbd, 0xc1, 0xf0, 0x09, 0xea, 0xce, 0xae, 0x0b, 0x50, 0xf5, 0xbe, 0xd7,
	0x2d, 0x1c, 0xdc, 0x77, 0xd7, 0xfe, 0xa5, 0xa4, 0x3e, 0xcf, 0x41, 0xc7, 0x19, 0x69, 0xaa, 0x67,
	0x5d, 0x63, 0xe0, 0xd1, 0x9f, 0x00, 0x00, 0x00, 0xff, 0xff, 0x6c, 0xe3, 0x8e, 0x23, 0x80, 0x04,
	0x00, 0x00,
}
